@@ -2,10 +2,7 @@
 from typing import TYPE_CHECKING, Dict, List, Optional, TypedDict, cast
 
 from ..event import Event, EventBase
-from .association import (
-    AssociationGroup,
-    Association,
-)
+from .association import Association, AssociationGroup
 from .node import Node
 
 if TYPE_CHECKING:
@@ -32,6 +29,7 @@ class ControllerDataType(TypedDict, total=False):
     supportedFunctionTypes: List[int]
     sucNodeId: int
     supportsTimers: bool
+    isHealNetworkActive: bool
 
 
 class Controller(EventBase):
@@ -146,6 +144,11 @@ class Controller(EventBase):
         """Return supports_timers."""
         return self.data.get("supportsTimers")
 
+    @property
+    def is_heal_network_active(self) -> bool:
+        """Return is_heal_network_active."""
+        return self.data["isHealNetworkActive"]
+
     async def async_begin_inclusion(
         self, include_non_secure: Optional[bool] = None
     ) -> bool:
@@ -318,15 +321,25 @@ class Controller(EventBase):
             }
         )
 
-    async def async_remove_node_from_all_assocations(self, node_id: int) -> None:
-        """Send removeNodeFromAllAssocations command to Controller."""
+    async def async_remove_node_from_all_associations(self, node_id: int) -> None:
+        """Send removeNodeFromAllAssociations command to Controller."""
         await self.client.async_send_command(
             {
-                "command": "controller.remove_node_from_all_assocations",
+                "command": "controller.remove_node_from_all_associations",
                 "nodeId": node_id,
             }
         )
 
+    async def async_get_node_neighbors(self, node_id: int) -> List[int]:
+        """Send getNodeNeighbors command to Controller to get node's neighbors."""
+        data = await self.client.async_send_command(
+            {
+                "command": "controller.get_node_neighbors",
+                "nodeId": node_id,
+            }
+        )
+        return cast(List[int], data["neighbors"])
+
     def receive_event(self, event: Event) -> None:
         """Receive an event."""
         if event.data["source"] == "node":
@@ -378,6 +391,10 @@ class Controller(EventBase):
 
     def handle_heal_network_progress(self, event: Event) -> None:
         """Process a heal network progress event."""
+        # pylint: disable=unused-argument
+        self.data["isHealNetworkActive"] = True
 
     def handle_heal_network_done(self, event: Event) -> None:
         """Process a heal network done event."""
+        # pylint: disable=unused-argument
+        self.data["isHealNetworkActive"] = False
